Download PySkein — PySkein v0.3.1 documentation

### Navigation

- index
- previous |
- PySkein v0.3.1 documentation »

# Download PySkein

New in version 0.3.1:
  - Improved demo script `threefish`
  - Better compatibility with Python 3.1
Download:
  - Source distribution: pyskein-0.3.1.tar.gz (sig)
  - Windows installer (only for Python 3.1): pyskein-0.3.1.win32-py3.1.exe (sig)

## Previous versions

- PySkein 0.3
    - New in this version:
        - Threefish block decryption
        - Demo scripts `skeinsum` and `threefish`

    - Source: pyskein-0.3.tar.gz (sig)

- PySkein 0.2
    - New in this version:
        - Support for message authentication codes
        - Threefish block encryption (but no decryption)
        - Fixed one or two reference leaks

    - Source: pyskein-0.2.tar.gz (sig)

- PySkein 0.1
    - New in this version:
        - Skein-256, Skein-512, and Skein-1024 hashing

    - Source: pyskein-0.1.tar.gz (sig)

### Navigation

- index
- previous |
- PySkein v0.3.1 documentation »